package com.rnsdk.clvideo;

import com.castlabs.android.PlayerSDK;
import com.castlabs.sdk.downloader.DownloaderPlugin;
import com.castlabs.sdk.mediasession.MediaSessionPlugin;
import com.castlabs.sdk.subtitles.SubtitlesPlugin;
import com.castlabs.sdk.thumbs.ThumbsPlugin;
import com.facebook.react.ReactPackage;
import com.facebook.react.bridge.NativeModule;
import com.facebook.react.bridge.ReactApplicationContext;
import com.facebook.react.uimanager.ViewManager;
import com.rnsdk.clvideo.download.DownloadModule;
import com.rnsdk.clvideo.download.NotificationProvider;
import com.rnsdk.clvideo.thumbnail.ThumbnailViewManager;
import com.rnsdk.clvideo.video.VideoModule;
import com.rnsdk.clvideo.video.VideoViewManager;
import java.util.ArrayList;
import java.util.List;

/**
 * The class to bundle the video components and modules.
 */
public class VideoPackage implements ReactPackage {

  @Override
  public List<ViewManager> createViewManagers(ReactApplicationContext reactContext) {
    List<ViewManager> managers = new ArrayList<>();
    managers.add(new VideoViewManager(reactContext));
    managers.add(new ThumbnailViewManager(reactContext));
    return managers;
  }

  @Override
  public List<NativeModule> createNativeModules(ReactApplicationContext reactContext) {
    registerPlugins();
    List<NativeModule> modules = new ArrayList<>();
    modules.add(new VideoModule(reactContext));
    modules.add(new DownloadModule(reactContext));
    return modules;
  }

  private void registerPlugins() {
    PlayerSDK.ENABLE_ERROR_RESPONSE_BODY = true;
    PlayerSDK.register(new SubtitlesPlugin());
    PlayerSDK.register(new ThumbsPlugin(false));
    PlayerSDK.register(new DownloaderPlugin(new NotificationProvider()));
    PlayerSDK.register(new MediaSessionPlugin());
  }
}
