package com.rnsdk.clvideo.thumbnail;

import android.content.Context;
import android.graphics.Bitmap;
import android.util.AttributeSet;
import android.view.View;
import android.widget.FrameLayout;
import android.widget.ImageView;
import androidx.annotation.Nullable;
import com.facebook.react.bridge.Arguments;
import com.facebook.react.bridge.ReactContext;
import com.facebook.react.bridge.WritableMap;
import com.facebook.react.uimanager.events.RCTEventEmitter;
import com.rnsdk.clvideo.R;

/**
 * The view component for thumbnail.
 */
public class ThumbnailView extends FrameLayout {

  private static final String TAG = "ThumbnailView";

  private FrameLayout mainView;
  private ImageView thumbnailView;
  private boolean createEventSent = false;

  public ThumbnailView(Context context, @Nullable AttributeSet attrs) {
    super(context, attrs);
    initialize();
  }

  private void initialize() {
    mainView = (FrameLayout) View.inflate(getContext(), R.layout.view_thumbnail, null);
    thumbnailView = mainView.findViewById(R.id.thumbnailView);
    addView(mainView);
  }

  private void onViewCreatedEvent() {
    ThumbnailInstanceManager.addInstance(getId(), this);
    WritableMap event = Arguments.createMap();
    event.putInt("instanceId", getId());
    createEvent(event, ThumbnailViewManager.EVENT_VIEW_CREATED);
  }

  private void createEvent(WritableMap event, String name) {
    ReactContext reactContext = (ReactContext) getContext();
    reactContext.getJSModule(RCTEventEmitter.class).receiveEvent(getId(), name, event);
  }

  public void setImageBitmap(Bitmap bitmap) {
    thumbnailView.setImageBitmap(bitmap);
  }

  public void release() {
    ThumbnailInstanceManager.removeInstance(getId());
  }

  @Override
  protected void onLayout(boolean changed, int left, int top, int right, int bottom) {
    super.onLayout(changed, left, top, right, bottom);
    if (!createEventSent) {
      onViewCreatedEvent();
    }
    createEventSent = true;
  }
}
