package com.rnsdk.clvideo.utils;

import com.castlabs.analytics.AnalyticsMetaData;
import com.castlabs.android.PlayerSDK;
import com.castlabs.sdk.youbora.YouboraPlugin;
import com.facebook.react.bridge.ReadableMap;
import com.npaw.core.options.AnalyticsOptions;

/**
 * Utility class for analytics.
 */
public class Analytics {

  /**
   * Creates and add specific metadata for each analytics library.
   *
   * @param analyticsMetaData The analytics metadata
   * @return the instance of final {@link AnalyticsMetaData}
   */
  public static AnalyticsMetaData createSpecificMetadata(AnalyticsMetaData analyticsMetaData) {
    // Youbora metadata
    analyticsMetaData = addYouboraMetadata(analyticsMetaData);

    // Add other analytics metadata here

    // Return final metadata
    return analyticsMetaData;
  }

  /**
   * Registers {@link YouboraPlugin} to the SDK.
   *
   * @param initData The initial data used to create the {@link YouboraPlugin}
   * @throws Exception Any exception during registration
   */
  public static void registerYouboraPlugin(ReadableMap initData) throws Exception {
    if (!initData.hasKey("analytics")) {
      return;
    }
    ReadableMap analyticsMap = initData.getMap("analytics");
    if (analyticsMap == null || !analyticsMap.hasKey("youbora")) {
      return;
    }
    ReadableMap youboraMap = analyticsMap.getMap("youbora");
    if (youboraMap == null || !youboraMap.hasKey("accountCode")) {
      throw new Exception("Couldn't find accountCode for Youbora analytics");
    }
    String accountCode = youboraMap.getString("accountCode");
    if (accountCode == null) {
      throw new Exception("Youbora accountCode is null");
    }
    YouboraPlugin youboraPlugin = new YouboraPlugin(accountCode);
    PlayerSDK.register(youboraPlugin);
  }

  private static AnalyticsMetaData addYouboraMetadata(AnalyticsMetaData analyticsMetaData) {
    AnalyticsOptions options = new AnalyticsOptions();
    options.setContentTitle(analyticsMetaData.assetId);
    return YouboraPlugin.createMetadata(analyticsMetaData, options);
  }
}
