package com.rnsdk.clvideo.video;

import android.util.Log;
import androidx.annotation.NonNull;
import com.facebook.react.bridge.ReactApplicationContext;
import com.facebook.react.common.MapBuilder;
import com.facebook.react.uimanager.ThemedReactContext;
import com.facebook.react.uimanager.ViewGroupManager;
import com.facebook.react.uimanager.annotations.ReactProp;
import java.util.Map;
import org.json.JSONException;

/**
 * The view manager for {@link VideoView}.
 */
public class VideoViewManager extends ViewGroupManager<VideoView> {
  public static final String REACT_CLASS = "VideoView";

  public static final String EVENT_VIEW_CREATED = "onViewCreated";
  public static final String EVENT_STATE_CHANGED = "onStateChanged";
  public static final String EVENT_ERROR = "onError";
  public static final String EVENT_SEEK_TO = "onSeekTo";
  public static final String EVENT_SEEK_COMPLETED = "onSeekCompleted";
  public static final String EVENT_FULLY_BUFFERED = "onFullyBuffered";
  public static final String EVENT_THUMBNAIL_LOADED = "onThumbnailLoaded";
  public static final String EVENT_PLAYER_MODEL_CHANGED = "onPlayerModelChanged";
  public static final String EVENT_PLAYLIST_ITEM_CHANGED = "onPlaylistItemChanged";
  public static final String EVENT_PLAYLIST_ENDED = "onPlaylistEnded";

  ReactApplicationContext applicationContext;

  public VideoViewManager(ReactApplicationContext reactContext) {
    applicationContext = reactContext;
  }

  @Override
  @NonNull
  public String getName() {
    return REACT_CLASS;
  }

  @Override
  protected VideoView createViewInstance(ThemedReactContext reactContext) {
    return new VideoView(reactContext, null);
  }

  @Override
  public void onDropViewInstance(@NonNull VideoView view) {
    super.onDropViewInstance(view);
    view.release();
  }

  @ReactProp(name = "mediaLoadRequest")
  public void setMediaLoadRequest(
      @NonNull final VideoView view,
      @NonNull final String jsMediaLoadRequest
  ) {
    view.setMediaLoadRequest(jsMediaLoadRequest);
  }

  @Override
  public Map<String, Object> getExportedCustomDirectEventTypeConstants() {
    return MapBuilder.<String, Object>builder()
      .put(EVENT_VIEW_CREATED, MapBuilder.of("registrationName", EVENT_VIEW_CREATED))
      .put(EVENT_STATE_CHANGED, MapBuilder.of("registrationName", EVENT_STATE_CHANGED))
      .put(EVENT_ERROR, MapBuilder.of("registrationName", EVENT_ERROR))
      .put(EVENT_SEEK_TO, MapBuilder.of("registrationName", EVENT_SEEK_TO))
      .put(EVENT_SEEK_COMPLETED, MapBuilder.of("registrationName", EVENT_SEEK_COMPLETED))
      .put(EVENT_FULLY_BUFFERED, MapBuilder.of("registrationName", EVENT_FULLY_BUFFERED))
      .put(EVENT_THUMBNAIL_LOADED, MapBuilder.of("registrationName", EVENT_THUMBNAIL_LOADED))
      .put(EVENT_PLAYER_MODEL_CHANGED,
          MapBuilder.of("registrationName", EVENT_PLAYER_MODEL_CHANGED))
      .put(EVENT_PLAYLIST_ITEM_CHANGED,
          MapBuilder.of("registrationName", EVENT_PLAYLIST_ITEM_CHANGED))
      .put(EVENT_PLAYLIST_ENDED, MapBuilder.of("registrationName", EVENT_PLAYLIST_ENDED))
      .build();
  }
}
