import React, {useEffect} from 'react';
import {View, StatusBar} from 'react-native';
import {NavigationContainer} from '@react-navigation/native';
import ScreenTags from './src/screens/ScreenTags';
import Colors from './src/utils/Colors';
import MainScreen from './src/screens/MainScreen';
import PlayerScreen from './src/screens/PlayerScreen';
import DemosScreen from './src/screens/DemosScreen';
import AppleTVDemosScreen from './src/screens/AppleTVDemosScreen';
import DownloadScreen from './src/screens/DownloadScreen';
import CLVideo from '../src/components/CLVideo';
import {createNativeStackNavigator} from '@react-navigation/native-stack';
import {navigationRef} from './src/services/NavigationService';

const Stack = createNativeStackNavigator();

export default function App() {
  useEffect(() => {
    let initData = {
      licenseKey: {
        android:
          'eyJ0eXAiOiJKV1QiLCJhbGciOiJSUzI1NiJ9.eyJwYWNrYWdlTmFtZSI6ImNvbS5leGFtcGxlIiwic2hhMSI6IjVFOjhGOjE2OjA2OjJFOkEzOkNEOjJDOjRBOjBEOjU0Ojc4Ojc2OkJBOkE2OkYzOjhDOkFCOkY2OjI1Iiwia2lkIjozMTQ1LCJpbHYiOmZhbHNlfQ.TrpLF5iDHI3M7gbQvZk-MVYvYGuuDrjHHLVUfgZ5RbxMtwY0Wj6EHztmR-nWoYpyquGejqLM6ihVBICwQsRrTVDpSjBgA5BjPAJg_gC_bRcQCS5ZXtcB7VaFKZg97MKMBywSmaPNN1wjnqKmwa-C5o-l6brCI-2buti41jjO_MWUmvuQp3MCddPjSjM-digkUDyp7wZkVb4xqG3dVSM0R9JpwASEUvfQ4Os15Uu16-auJZN8dd_9DZuLjY1S2yJGya0q9JCG7jHJhbowZAGo4SRRCvBkKMUghIPWmAx1aEwVJ4o1Hsos664e6pReODeNexro7S6nG1dfVpjGxgyPdQ',
        iOS: 'eyJhbGciOiJSUzI1NiIsInR5cCI6IkpXVCJ9.eyJidW5kbGVJZCI6ImNvbS5jYXN0bGFicy5STkRlbW8iLCJraWQiOjM0OTYsImlsdiI6ZmFsc2V9.JBdID7cj2kc4dHjEdXyT4VTuwChlXgnez1EMnaywhQKGM6pQ8UQ1rnSewwL9eiMl6jNRhQs7t9g705aXhJm5uaf6Om8en0_eQbfePaZEzweFN_8bMOojlXjIBuGsp3c2DMu7fmgat7SOyjvm0lBVinTxG_qusuHh6Xvl2MCdPlWZv5kEfKTvyJpzHIPzfBe7Bfa7BwQs5T27pj-bQ4mtMzW-xeeKiOjC19Sgi_8YGR1yPxh_9Ww-efrZ1CewNCDcFwZvSiF6p8lJgQzjmSmEomeIuPsufGZPGlggfqNWdSALh6fth98i_aQXTOT_LpGU9_kbRrG_Nux5nCeWHf6jOw',
        tvOS: 'eyJhbGciOiJSUzI1NiIsInR5cCI6IkpXVCJ9.eyJidW5kbGVJZCI6ImNvbS5jYXN0bGFicy5STkRlbW8iLCJraWQiOjM1MzAsImlsdiI6ZmFsc2V9.oFQxzHnQXvfeu1qcsPh7aXpEH4G9ft7djrOvVc0NExP0L3c31aDDbjYtsnSV8C9Voj33RaxXIWrTeTTPiSfQYpUkSeC0XhRpkO_2wbVphlQBq2LiJReiGUP0L9h6Q0bp-Gu8MGhdMBwPVo3yQJGmem2S85Ky-1xhpKiE_3Yv7BfvVRU-Jj7wiAfafYjtfa6R711_KXtlc8O7oJe0aDLcCpWzwagNBTD-E2LPpCm0UdGz8Kvy38p6s66WIjC_iWCHBKeUiYStYFc6osMq49FR0C_dqbTotnOOsQeBiDuAqGAg4SsQ7AHO92yCyFs5TXWOh3zJWY5kT2-1XvATH5WWmA',
      },
      analytics: {
        youbora: {
          accountCode: 'castlabsdev',
        },
      },
    };

    CLVideo.initialize(initData);
  }, []);

  return (
    <View style={{flex: 1}}>
      <StatusBar backgroundColor={Colors.theme1} barStyle="light-content" />
      <NavigationContainer ref={navigationRef}>
        <Stack.Navigator screenOptions={{headerShown: false}}>
          <Stack.Screen name={ScreenTags.Main} component={MainScreen} />
          <Stack.Screen name={ScreenTags.Player} component={PlayerScreen} />
          <Stack.Screen name={ScreenTags.Demos} component={DemosScreen} />
          <Stack.Screen
            name={ScreenTags.AppleTVDemos}
            component={AppleTVDemosScreen}
          />
          <Stack.Screen name={ScreenTags.Download} component={DownloadScreen} />
        </Stack.Navigator>
      </NavigationContainer>
    </View>
  );
}
