import Demo from '../models/Demo';
import {
  AndroidSecondaryDisplayBehaviour,
  ContentType,
  DrmSystem,
  DrmTodayEnvironment,
  DrmType,
  SecondaryDisplayBehaviour,
  SilentSwitchBehaviour,
  TrackType,
} from '../../../src';

const demoList: Demo[] = [
  {
    // TODO remove before merging
    id: '5000',
    title: 'RN-385',
    description: 'Encrypted start-over dash stream with Widevine',
    media: {
      autoPlay: true,
      source: {
        url: 'https://vxtest.vcdn1.streaming.proximustv.be/sdash/LIVE$OTT243224/index.mpd,pxtoken=eC1tYWMtYWRkcmVzcz1ERUJBQUFBRDQ1MSZwYXRoVVJJPSUyRnNkYXNoJTJBJmV4cGlyeT0xNzM1OTA5ODYyJmZuPXNoYTI1NiZwdWJsaXNoZXI9MTIxMiZjLWlwLXVubG9ja2VkPTEsNTY5NTM5MTZFOUEwMDIyQjk4OTU0RkFEQkU1RUNFNjJEMDA3NkJEQjQ0OUJFQjYzOUNBMTdFRUJFRUU3QTY2Rg==/Manifest?start=2024-12-04T13:00:00Z&end=2024-12-04T15:00:00Z&device=DTVOH',
        drmProtected: false,
        type: ContentType.DASH,
      },
    },
    showOnApple: false,
    showOnAndroid: true,
    canCast: false,
  },
  {
    id: '100',
    title: 'Chromecast: Clear VoD 2',
    description: 'Unencrypted stream, multiaudio + multisubs',
    media: {
      autoPlay: true,
      userId: 'userId:123',
      source: [
        {
          url: 'https://castlabs-dl.s3.eu-west-1.amazonaws.com/public/Transcodes/OUT/LHENCODING-156/202110/cccccccc-bbbb-cccc-dddd-cccccccccccc_CA_2018_QA_CMAFU/master.m3u8',
        },
        {
          url: 'https://castlabs-dl.s3.eu-west-1.amazonaws.com/public/Transcodes/OUT/LHENCODING-156/202110/cccccccc-bbbb-cccc-dddd-cccccccccccc_CA_2018_QA_CMAFU/dash.mpd',
        },
      ],
    },
    showOnApple: true,
    showOnAndroid: true,
    canCast: true,
  },
  {
    id: '101',
    title: 'Chromecast: Protected Live 1',
    description: 'Protected stream',
    media: {
      autoPlay: true,
      userId: 'userId:123',
      source: [
        {
          url: 'https://usp-demo.castlabs.com/live/channel3/channel3.isml/hls.m3u8',
          drmProtected: true,
        },
        {
          url: 'https://usp-demo.castlabs.com/live/channel3/channel3.isml/channel3.mpd',
          drmProtected: true,
        },
      ],
      drmType: DrmType.DRMTODAY,
      drmConfiguration: {
        environment: DrmTodayEnvironment.STAGING,
        userId: 'purchase',
        sessionId: 'default',
        merchant: 'six',
      },
    },
    showOnApple: true,
    showOnAndroid: true,
    canCast: true,
  },
  {
    id: '102',
    title: 'Chromecast: Clear VoD 2',
    description: 'Unencrypted stream, multiaudio + multisubs',
    media: {
      autoPlay: true,
      userId: 'userId:123',
      source: [
        {
          url: 'https://castlabs-dl.s3.eu-west-1.amazonaws.com/public/Transcodes/OUT/LHENCODING-156/202110/cccccccc-bbbb-cccc-dddd-cccccccccccc_CA_2018_QA_CMAFU/master.m3u8',
        },
      ],
      preferredTextLanguage: 'en',
    },
    showOnApple: true,
    showOnAndroid: true,
    canCast: false,
  },
  {
    id: '1',
    title: 'MP4',
    description: 'MP4 stream with autoPlay off',
    media: {
      autoPlay: false,
      source:
        'http://commondatastorage.googleapis.com/gtv-videos-bucket/sample/ElephantsDream.mp4',
      analyticsMetaData: {
        live: false,
        assetId: 'Mp4',
        viewerId: 'user-id',
      },
    },
    showOnApple: true,
    showOnAndroid: true,
    canCast: false,
  },
  {
    id: '2',
    title: 'Clear DASH VoD 1',
    description: 'Unencrypted dash stream, offset 10sec',
    media: {
      autoPlay: true,
      source: 'https://demo.cf.castlabs.com/media/prestodash/Manifest.mpd',
      startTimeMs: 10000,
      analyticsMetaData: {
        live: false,
        assetId: 'Clear DASH VoD 1',
        viewerId: 'user-id',
      },
    },
    showOnApple: false,
    showOnAndroid: true,
    canCast: false,
  },
  {
    id: '3',
    title: 'Clear DASH VoD 2',
    description: 'Unencrypted dash stream, multiaudio + multisubs',
    media: {
      autoPlay: true,
      source:
        'https://demo.cf.castlabs.com/media/TOS/abr/Manifest_clean_sizes.mpd',
      analyticsMetaData: {
        live: false,
        assetId: 'Clear DASH VoD 2',
        viewerId: 'user-id',
      },
    },
    showOnApple: false,
    showOnAndroid: true,
    canCast: false,
  },
  {
    id: '4',
    title: 'Encrypted DASH VoD (DRMToday DRM)',
    description: 'Encrypted dash stream with Widevine',
    media: {
      autoPlay: true,
      source: {
        url: 'https://demo.cf.castlabs.com/media/TOS/DASH/DEMO.mpd',
        drmProtected: true,
      },
      drmType: DrmType.DRMTODAY,
      drmSystem: DrmSystem.WIDEVINE,
      drmConfiguration: {
        environment: DrmTodayEnvironment.STAGING,
        userId: 'purchase',
        sessionId: 'sessionId',
        merchant: 'six',
        assetId: 'dasheverywhere_demo',
      },
      analyticsMetaData: {
        live: false,
        assetId: 'Encrypted DASH VoD (DRMToday DRM)',
        viewerId: 'user-id',
      },
    },
    showOnApple: false,
    showOnAndroid: true,
    canCast: false,
  },
  {
    id: '5',
    title: 'Encrypted DASH VoD (Custom DRM)',
    description: 'Encrypted dash stream with Widevine',
    media: {
      autoPlay: true,
      source: {
        url: 'https://storage.googleapis.com/wvmedia/cenc/h264/tears/tears.mpd',
        drmProtected: true,
      },
      drmType: DrmType.CUSTOM,
      drmSystem: DrmSystem.WIDEVINE,
      drmConfiguration: {
        WIDEVINE: {
          licensingUrl:
            'https://proxy.uat.widevine.com/proxy?video_id=efd045b1eb61888a&provider=widevine_test',
        },
      },
      analyticsMetaData: {
        live: false,
        assetId: 'Encrypted DASH VoD (Custom DRM)',
        viewerId: 'user-id',
      },
    },
    showOnApple: false,
    showOnAndroid: true,
    canCast: false,
  },
  {
    id: '6',
    title: 'Clear DASH Live',
    description: 'Unencrypted live dash stream',
    media: {
      autoPlay: true,
      source: 'https://livedash.castlabs.com/livesim/petv/Manifest.mpd',
      analyticsMetaData: {
        live: true,
        assetId: 'Clear DASH Live',
        viewerId: 'user-id',
      },
    },
    showOnApple: false,
    showOnAndroid: true,
    canCast: false,
  },
  {
    id: '7',
    title: 'Encrypted DASH Live',
    description: 'Encrypted live dash stream with Widevine',
    media: {
      autoPlay: true,
      source: {
        url: 'https://livedash.castlabs.com/livesim/petv_drm/Manifest.mpd',
        drmProtected: true,
      },
      drmType: DrmType.DRMTODAY,
      drmSystem: DrmSystem.WIDEVINE,
      drmConfiguration: {
        environment: DrmTodayEnvironment.STAGING,
        userId: 'purchase',
        sessionId: 'default',
        merchant: 'six',
        assetId: 'petv_drm',
      },
      analyticsMetaData: {
        live: true,
        assetId: 'Encrypted DASH Live',
        viewerId: 'user-id',
      },
    },
    showOnApple: false,
    showOnAndroid: true,
    canCast: false,
  },
  {
    id: '8',
    title: 'Clear HLS VoD 1',
    description: 'Unencrypted hls stream, offset 10sec',
    media: {
      autoPlay: true,
      source: 'https://demo.cf.castlabs.com/media/prestohls/master.m3u8',
      startTimeMs: 10000,
      analyticsMetaData: {
        live: false,
        assetId: 'Clear HLS VoD 1',
        viewerId: 'user-id',
      },
    },
    showOnApple: true,
    showOnAndroid: true,
    canCast: false,
  },
  {
    id: '9',
    title: 'Clear HLS VoD 2',
    description: 'Unencrypted hls stream, multiaudio + multisubs',
    media: {
      autoPlay: true,
      source:
        'https://demo.cf.castlabs.com/media/QA/hls-short-multiaudio-multisub/playlist.m3u8',
      analyticsMetaData: {
        live: false,
        assetId: 'Clear HLS VoD 2',
        viewerId: 'user-id',
      },
    },
    showOnApple: true,
    showOnAndroid: true,
    canCast: false,
  },
  {
    id: '10',
    title: 'Encrypted HLS VoD',
    description: 'Encrypted hls stream with Fairplay',
    media: {
      autoPlay: true,
      source: {
        url: 'https://demo.cf.castlabs.com/media/fps/prog_index.m3u8',
        drmProtected: true,
      },
      drmType: DrmType.DRMTODAY,
      drmSystem: DrmSystem.FAIRPLAY,
      drmConfiguration: {
        environment: DrmTodayEnvironment.STAGING,
        userId: 'rental1',
        sessionId: 'p0',
        merchant: 'six',
        assetId: 'twelve',
      },
      analyticsMetaData: {
        live: false,
        assetId: 'Encrypted HLS VoD',
        viewerId: 'user-id',
      },
    },
    showOnApple: true,
    showOnAndroid: false,
    canCast: false,
  },
  {
    id: '11',
    title: 'Clear HLS Live',
    description: 'Unencrypted live hls stream',
    media: {
      autoPlay: true,
      source:
        'https://usp-demo.castlabs.com/live/channel1/channel1.isml/hls.m3u8',
      analyticsMetaData: {
        live: true,
        assetId: 'Clear HLS Live',
        viewerId: 'user-id',
      },
    },
    showOnApple: true,
    showOnAndroid: true,
    canCast: false,
  },
  {
    id: '12',
    title: 'Encrypted HLS Live',
    description: 'Encrypted live hls stream with Fairplay',
    media: {
      autoPlay: true,
      source: {
        url: 'https://usp-demo.castlabs.com/live/channel3/channel3.isml/hls.m3u8',
        drmProtected: true,
      },
      drmType: DrmType.DRMTODAY,
      drmSystem: DrmSystem.FAIRPLAY,
      drmConfiguration: {
        environment: DrmTodayEnvironment.STAGING,
        userId: 'purchase',
        sessionId: 'default',
        merchant: 'six',
      },
      analyticsMetaData: {
        live: true,
        assetId: 'Encrypted HLS Live',
        viewerId: 'user-id',
      },
    },
    showOnApple: true,
    showOnAndroid: false,
    canCast: false,
  },
  {
    id: '13',
    title: 'Playlist',
    description: 'Plays 4 unencrypted hls streams, 2nd assets has offset 20sec',
    media: [
      {
        autoPlay: true,
        source: 'https://demo.cf.castlabs.com/media/prestohls/master.m3u8',
        analyticsMetaData: {
          live: false,
          assetId: 'Playlist - item 1',
          viewerId: 'user-id',
        },
      },
      {
        autoPlay: true,
        source:
          'https://devstreaming-cdn.apple.com/videos/streaming/examples/bipbop_4x3/bipbop_4x3_variant.m3u8',
        startTimeMs: 20000,
        analyticsMetaData: {
          live: false,
          assetId: 'Playlist - item 2',
          viewerId: 'user-id',
        },
      },
      {
        autoPlay: true,
        source:
          'https://demo.cf.castlabs.com/media/QA/hls-short-multiaudio-multisub/playlist.m3u8',
        analyticsMetaData: {
          live: false,
          assetId: 'Playlist - item 3',
          viewerId: 'user-id',
        },
      },
      {
        autoPlay: true,
        source:
          'https://devstreaming-cdn.apple.com/videos/streaming/examples/bipbop_4x3/bipbop_4x3_variant.m3u8',
        analyticsMetaData: {
          live: false,
          assetId: 'Playlist - item 4',
          viewerId: 'user-id',
        },
      },
    ],
    showOnApple: true,
    showOnAndroid: false,
    canCast: false,
  },
  {
    id: '14',
    title: 'Silent switch iOS',
    description: 'Unencrypted live hls stream',
    media: {
      autoPlay: true,
      source: 'https://demo.cf.castlabs.com/media/prestohls/master.m3u8',
      ignoreSilentSwitch: SilentSwitchBehaviour.OBEY,
      analyticsMetaData: {
        live: true,
        assetId: 'Silent switch iOS',
        viewerId: 'user-id',
      },
    },
    showOnApple: true,
    showOnAndroid: false,
    canCast: false,
  },
  {
    // this will not work on ios until RN-74 is fixed
    id: '15',
    title: 'Side-loaded subtitles',
    description: 'Unencrypted stream with side-loaded vtt, ttml and srt subs',
    media: {
      autoPlay: true,
      source:
        'http://commondatastorage.googleapis.com/gtv-videos-bucket/sample/ElephantsDream.mp4',
      sideloadedTracks: [
        {
          trackType: TrackType.SUBTITLE,
          mimeType: 'text/vtt',
          url: 'https://demo.cf.castlabs.com/media/QA/hls-short-multiaudio-multisub/sub/120min_EN.vtt',
          language: 'EN',
          label: 'EN webVTT side-loaded',
          kind: 'subtitle',
        },
        {
          trackType: TrackType.SUBTITLE,
          // this should always be application/ttml+xml
          // otherwise android doesn't recognize it
          mimeType: 'application/ttml+xml',
          url: 'https://demo.cf.castlabs.com/media/TOS/abr/TOS-fr.xml',
          language: 'FR',
          label: 'FR TTML side-loaded',
          kind: 'subtitle',
        },
        {
          trackType: TrackType.SUBTITLE,
          mimeType: 'text/plain',
          url: 'https://raw.githubusercontent.com/Akhilan/malayalam-subtitles/master/Tears%20of%20Steel-%20Mango%20Open%20Movie%20ml.srt',
          language: 'ML',
          label: 'ML SRT side-loaded',
          kind: 'subtitle',
        },
      ],
      analyticsMetaData: {
        live: false,
        assetId: 'Side-loaded subtitles',
        viewerId: 'user-id',
      },
    },
    showOnApple: true,
    showOnAndroid: true,
    canCast: false,
  },

  {
    // this will show black thumbnail for ios until IOSP-3388 is implemented
    id: '16',
    title: 'Side-Loaded BIF Thumbnails Tracks',
    description: 'Plays an unencrypted stream, side-loading a Thumbnail track.',
    media: {
      autoPlay: true,
      source:
        'https://commondatastorage.googleapis.com/gtv-videos-bucket/sample/ElephantsDream.mp4',
      sideloadedTracks: [
        {
          trackType: TrackType.THUMBNAIL,
          url: 'http://demo.castlabs.com/media/TOS/thumbs/thumbs.bif',
        },
      ],
      analyticsMetaData: {
        live: false,
        assetId: 'Side-Loaded BIF Thumbnails Tracks',
        viewerId: 'user-id',
      },
    },
    showOnApple: true,
    showOnAndroid: true,
    canCast: false,
  },
  {
    id: '17',
    title: 'Side-Loaded GRID 10x10 Thumbnails Tracks',
    description: 'Plays an unencrypted stream, side-loading a Thumbnail track.',
    media: {
      autoPlay: true,
      source:
        'https://commondatastorage.googleapis.com/gtv-videos-bucket/sample/ElephantsDream.mp4',
      sideloadedTracks: [
        {
          trackType: TrackType.THUMBNAIL,
          url: 'https://demo.cf.castlabs.com/media/Route66/dash/thumbs/$index$_7.jpg',
          gridWidth: 10,
          gridHeight: 10,
          intervalMs: 10000,
        },
      ],
      analyticsMetaData: {
        live: false,
        assetId: 'Side-Loaded GRID 10x10 Thumbnails Tracks',
        viewerId: 'user-id',
      },
    },
    showOnApple: true,
    showOnAndroid: true,
    canCast: false,
  },
  {
    id: '18',
    title: 'Side-Loaded GRID 1x1 Thumbnails Tracks',
    description: 'Plays an unencrypted stream, side-loading a Thumbnail track.',
    media: {
      autoPlay: true,
      source:
        'https://commondatastorage.googleapis.com/gtv-videos-bucket/sample/ElephantsDream.mp4',
      sideloadedTracks: [
        {
          trackType: TrackType.THUMBNAIL,
          url: 'https://demo.cf.castlabs.com/media/Route66/dash/thumbs/$index$.jpg',
          gridWidth: 1,
          gridHeight: 1,
          intervalMs: 10000,
        },
      ],
      analyticsMetaData: {
        live: false,
        assetId: 'Side-Loaded GRID 1x1 Thumbnails Tracks',
        viewerId: 'user-id',
      },
    },
    showOnApple: true,
    showOnAndroid: true,
    canCast: false,
  },
  {
    id: '19',
    title: 'Side-Loaded VTT Thumbnails Tracks',
    description: 'Plays an unencrypted stream, side-loading a Thumbnail track.',
    media: {
      autoPlay: true,
      source:
        'https://commondatastorage.googleapis.com/gtv-videos-bucket/sample/ElephantsDream.mp4',
      sideloadedTracks: [
        {
          trackType: TrackType.THUMBNAIL,
          url: 'https://demo.cf.castlabs.com/media/Route66/dash/thumbs/thumbs.vtt',
        },
      ],
      analyticsMetaData: {
        live: false,
        assetId: 'Side-Loaded VTT Thumbnails Tracks',
        viewerId: 'user-id',
      },
    },
    showOnApple: true,
    showOnAndroid: true,
    canCast: false,
  },
  {
    id: '20',
    title: 'In-stream Thumbnails Tracks VoD',
    description:
      'Plays an unencrypted vod stream, with in-stream Thumbnail track.',
    media: {
      autoPlay: true,
      source:
        'https://demo.cf.castlabs.com/media/QA/dash-if-vod-thumbnails/manifest.mpd',
      analyticsMetaData: {
        live: false,
        assetId: 'In-stream Thumbnails Tracks VoD',
        viewerId: 'user-id',
      },
    },
    showOnApple: false,
    showOnAndroid: true,
    canCast: false,
  },
  {
    id: '21',
    title: 'In-stream Thumbnails Tracks Live',
    description:
      'Plays an unencrypted live stream, with in-stream Thumbnail track.',
    media: {
      autoPlay: true,
      source:
        'https://d24rwxnt7vw9qb.cloudfront.net/out/v1/4577dca5f8a44756875ab5cc913cd1f1/index.mpd',
      analyticsMetaData: {
        live: true,
        assetId: 'In-stream Thumbnails Tracks Live',
        viewerId: 'user-id',
      },
    },
    showOnApple: false,
    showOnAndroid: true,
    canCast: false,
  },
  {
    id: '22',
    title: 'HLS + IMSC1 subtitles',
    description: 'Plays an unencrypted stream, with IMSC1 text based subtitles',
    media: {
      autoPlay: true,
      source: {
        url: 'https://castlabs-dl.s3.eu-west-1.amazonaws.com/public/SUPPORT/TRAN88/9/tran88-9-no-styling.m3u8',
        drmProtected: true,
      },
      drmType: DrmType.DRMTODAY,
      drmSystem: DrmSystem.FAIRPLAY,
      drmConfiguration: {
        environment: DrmTodayEnvironment.STAGING,
        userId: 'purchase',
        sessionId: 'default',
        merchant: 'six',
      },
      analyticsMetaData: {
        live: false,
        assetId: 'HLS + IMSC1 subtitles',
        viewerId: 'user-id',
      },
    },
    showOnApple: true,
    showOnAndroid: false,
    canCast: false,
  },
  {
    id: '23',
    title: 'DASH + IMSC1 subtitles',
    description: 'Plays an unencrypted stream, with IMSC1 text based subtitles',
    media: {
      autoPlay: true,
      source: {
        url: 'https://castlabs-dl.s3.eu-west-1.amazonaws.com/public/SUPPORT/TRAN88/1/tran88-1.mpd',
        drmProtected: true,
      },
      drmType: DrmType.DRMTODAY,
      drmSystem: DrmSystem.WIDEVINE,
      drmConfiguration: {
        environment: DrmTodayEnvironment.STAGING,
        userId: 'purchase',
        sessionId: 'default',
        merchant: 'six',
      },
      analyticsMetaData: {
        live: false,
        assetId: 'DASH + IMSC1 subtitles',
        viewerId: 'user-id',
      },
    },
    showOnApple: false,
    showOnAndroid: true,
    canCast: false,
  },
  {
    id: '24',
    title: 'DASH + IMSC1 subtitles 1',
    description:
      'Plays an unencrypted stream, with IMSC1 image based subtitles',
    media: {
      autoPlay: true,
      source: {
        url: 'https://castlabs-dl.s3.eu-west-1.amazonaws.com/public/SUPPORT/TRAN88/2/tran88-2.mpd',
        drmProtected: true,
      },
      drmType: DrmType.DRMTODAY,
      drmSystem: DrmSystem.WIDEVINE,
      drmConfiguration: {
        environment: DrmTodayEnvironment.STAGING,
        userId: 'purchase',
        sessionId: 'default',
        merchant: 'six',
      },
      analyticsMetaData: {
        live: false,
        assetId: 'DASH + IMSC1 subtitles 1',
        viewerId: 'user-id',
      },
    },
    showOnApple: false,
    showOnAndroid: true,
    canCast: false,
  },
  {
    id: '25',
    title: 'DASH + IMSC1 subtitles 2',
    description:
      'Plays an unencrypted stream, with IMSC1 image based subtitles',
    media: {
      autoPlay: true,
      source: 'https://livesim.dashif.org/dash/vod/testpic_2s/imsc1_img.mpd',
      analyticsMetaData: {
        live: false,
        assetId: 'DASH + IMSC1 subtitles 2',
        viewerId: 'user-id',
      },
    },
    showOnApple: false,
    showOnAndroid: true,
    canCast: false,
  },
  {
    id: '26',
    title: 'DASH + SMPTE-TT subtitles',
    description:
      'Plays an unencrypted stream, with SMPTE-TT text based subtitles',
    media: {
      autoPlay: true,
      source: {
        url: 'https://castlabs-dl.s3.eu-west-1.amazonaws.com/public/SUPPORT/TRAN88/3/tran88-3.mpd',
        drmProtected: true,
      },
      drmType: DrmType.DRMTODAY,
      drmSystem: DrmSystem.WIDEVINE,
      drmConfiguration: {
        environment: DrmTodayEnvironment.STAGING,
        userId: 'purchase',
        sessionId: 'default',
        merchant: 'six',
      },
      analyticsMetaData: {
        live: false,
        assetId: 'DASH + SMPTE-TT subtitles',
        viewerId: 'user-id',
      },
    },
    showOnApple: false,
    showOnAndroid: true,
    canCast: false,
  },
  {
    id: '27',
    title: 'Buffer config',
    description: 'Plays an unencrypted dash stream.',
    media: {
      autoPlay: true,
      source:
        'http://demo.cf.castlabs.com/media/TOS/abr/Manifest_clean_sizes.mpd',
      analyticsMetaData: {
        live: false,
        assetId: 'Buffer config',
        viewerId: 'user-id',
      },
      android: {
        bufferConfiguration: {
          bufferSizeBytes: 1024 * 1024 * 6,
          lowMediaTimeMs: 1000 * 9,
          highMediaTimeMs: 1000 * 19,
          bufferSegmentSize: 1000 * 11,
          minPlaybackStartMs: 1000,
          minRebufferStartMs: 3000,
          prioritizeTimeOverSizeThresholds: true,
          audioFeedYieldEnabled: true,
          videoFeedYieldEnabled: true,
          drainWhileCharging: true,
          backBufferDurationMs: 20000,
        },
      },
    },
    showOnApple: false,
    showOnAndroid: true,
    canCast: false,
  },
  {
    id: '28',
    title: 'Nielsen HLS - 10s offset',
    description: 'Plays an unencrypted stream, with 10sec offset',
    media: {
      autoPlay: true,
      source: 'https://www.nielseninternet.com/id3sdk/CC-N2-FD/prog_index.m3u8',
      startTimeMs: 10000,
      analyticsMetaData: {
        live: false,
        assetId: 'Nielsen HLS - 10s offset',
        viewerId: 'user-id',
      },
    },
    showOnApple: true,
    showOnAndroid: true,
    canCast: false,
  },
  {
    id: '29',
    title: 'Clear HLS VoD 3',
    description: 'Plays an unencrypted stream, with 10sec offset',
    media: {
      autoPlay: true,
      source:
        'https://demo.cf.castlabs.com/public/HLS/gerard-test/ioss291-clear720/master.m3u8',
      startTimeMs: 10000,
      analyticsMetaData: {
        live: false,
        assetId: 'Clear HLS VoD 3',
        viewerId: 'user-id',
      },
    },
    showOnApple: true,
    showOnAndroid: true,
    canCast: false,
  },
  {
    id: '30',
    title: 'Playlist',
    description: '2 items',
    media: [
      {
        autoPlay: true,
        source: 'https://demo.cf.castlabs.com/media/prestodash/Manifest.mpd',
      },
      {
        autoPlay: true,
        source:
          'https://demo.cf.castlabs.com/media/TOS/abr/Manifest_clean_sizes.mpd',
      },
    ],
    showOnApple: false,
    showOnAndroid: true,
    canCast: false,
  },
  {
    id: '31',
    title: 'Allow secondary screen',
    description: 'Encrypted DASH, Allow secondary screen',
    media: {
      autoPlay: true,
      source: {
        url: 'https://demo.cf.castlabs.com/media/TOS/DASH/DEMO.mpd',
        drmProtected: true,
      },
      drmType: DrmType.DRMTODAY,
      drmSystem: DrmSystem.WIDEVINE,
      drmConfiguration: {
        environment: DrmTodayEnvironment.STAGING,
        userId: 'purchase',
        sessionId: 'sessionId',
        merchant: 'six',
        assetId: 'dasheverywhere_demo',
      },
      android: {
        secondaryDisplayBehaviour: AndroidSecondaryDisplayBehaviour.AllowAlways,
      },
    },
    showOnApple: false,
    showOnAndroid: true,
    canCast: false,
  },
  {
    id: '32',
    title: 'Allow secondary screen',
    description: 'Encrypted HLS, Allow secondary screen',
    media: {
      autoPlay: true,
      source: {
        url: 'https://demo.cf.castlabs.com/media/fps/prog_index.m3u8',
        drmProtected: true,
      },
      drmType: DrmType.DRMTODAY,
      drmSystem: DrmSystem.FAIRPLAY,
      drmConfiguration: {
        environment: DrmTodayEnvironment.STAGING,
        userId: 'rental1',
        sessionId: 'p0',
        merchant: 'six',
        assetId: 'twelve',
      },
      secondaryDisplayBehaviour: SecondaryDisplayBehaviour.AllowAlways,
    },
    showOnApple: true,
    showOnAndroid: false,
    canCast: false,
  },
];

export default demoList;
