import React, {Component} from 'react';
import {StyleSheet, Pressable, View} from 'react-native';
import Colors from '../utils/Colors';
import CLImage from './CLImage';

type Props = {
  isVisible?: boolean;
  style?: any;
  onPress?: () => void;
};

type States = {
  isVisible: boolean;
  isFocus: boolean;
};

class CLAudioButton extends Component<Props, States> {
  public isEnabled: boolean;
  private onImage: CLImage | null = null;
  private offImage: CLImage | null = null;

  public constructor(props: Props) {
    super(props);

    this.state = {
      isVisible: props.isVisible !== undefined ? props.isVisible : true,
      isFocus: false,
    };

    this.isEnabled = true;
  }

  render() {
    if (this.state.isVisible) {
      return (
        <Pressable
          style={this.props.style}
          onFocus={() => {
            this.setState({isFocus: true});
          }}
          onBlur={() => {
            this.setState({isFocus: false});
          }}
          onPress={() => {
            if (this.props.onPress) {
              this.props.onPress();
            }
          }}>
          <View style={this.state.isFocus ? styles.onFocus : styles.onBlur}>
            <CLImage
              ref={onImage => {
                this.onImage = onImage;
              }}
              style={styles.on}
              imageStyle={styles.onImage}
              isVisible={this.isEnabled}
              disabled={true}
              source={require('../assets/images/sound_on.png')}
            />
            <CLImage
              ref={offImage => {
                this.offImage = offImage;
              }}
              style={styles.off}
              imageStyle={styles.offImage}
              isVisible={!this.isEnabled}
              disabled={true}
              source={require('../assets/images/sound_off.png')}
            />
          </View>
        </Pressable>
      );
    } else {
      return null;
    }
  }

  public enable() {
    this.isEnabled = true;
    this.refresh();
  }

  public disable() {
    this.isEnabled = false;
    this.refresh();
  }

  private refresh() {
    this.onImage?.setState({isVisible: this.isEnabled});
    this.offImage?.setState({isVisible: !this.isEnabled});
  }
}

const styles = StyleSheet.create({
  on: {
    width: '100%',
    height: '100%',
    position: 'absolute',
    justifyContent: 'center',
    alignItems: 'center',
  },
  off: {
    width: '100%',
    height: '100%',
    position: 'absolute',
    justifyContent: 'center',
    alignItems: 'center',
  },
  onImage: {
    width: '70%',
    height: '70%',
    tintColor: '#FFFFFF',
  },
  offImage: {
    width: '70%',
    height: '70%',
    tintColor: '#FFFFFF',
  },
  onFocus: {
    width: '100%',
    height: '100%',
    backgroundColor: Colors.buttonFocus,
  },
  onBlur: {
    width: '100%',
    height: '100%',
    backgroundColor: 'transparent',
  },
});

export default CLAudioButton;
