import React, {Component} from 'react';
import {StyleSheet, Pressable, Text} from 'react-native';
import Colors from '../utils/Colors';

type Props = {
  isVisible?: boolean;
  text: string;
  enabled?: boolean;
  style?: any;
  onPress?: () => void;
};

type States = {
  isVisible: boolean;
  text: string;
  enabled: boolean;
};

class CLButton extends Component<Props, States> {
  public constructor(props: Props) {
    super(props);

    this.state = {
      isVisible: props.isVisible !== undefined ? props.isVisible : true,
      text: props.text,
      enabled: props.enabled !== undefined ? props.enabled : true,
    };
  }

  render() {
    if (this.state.isVisible) {
      return (
        <Pressable
          style={[
            styles.container,
            this.props.style,
            {opacity: this.state.enabled ? 1 : 0.6},
          ]}
          onPress={() => {
            if (this.props.onPress && this.state.enabled) {
              this.props.onPress();
            }
          }}>
          <Text style={styles.text}> {this.state.text} </Text>
        </Pressable>
      );
    } else {
      return null;
    }
  }
}

const styles = StyleSheet.create({
  container: {
    alignSelf: 'baseline',
    backgroundColor: Colors.theme1,
    borderRadius: 5,
    padding: 3,
    marginLeft: 3,
    marginRight: 3,
  },
  text: {
    color: Colors.theme2,
    fontSize: 12,
    fontWeight: '600',
  },
});

export default CLButton;
