import React, {Component} from 'react';
import {Image, StyleSheet, Pressable, ImageResizeMode} from 'react-native';

type Props = {
  isVisible?: boolean;
  opacity?: number;
  disabled?: boolean;
  source?: any;
  resizeMode?: ImageResizeMode;
  style?: any;
  imageStyle?: any;
  onPress?: () => void;
};

type States = {
  isVisible: boolean;
  opacity: number;
  disabled: boolean;
  source: any;
};

class CLImage extends Component<Props, States> {
  public constructor(props: Props) {
    super(props);

    this.state = {
      isVisible: props.isVisible !== undefined ? props.isVisible : true,
      opacity: props.opacity !== undefined ? props.opacity : 1,
      disabled: props.disabled !== undefined ? props.disabled : false,
      source: props.source,
    };
  }

  render() {
    if (this.state.isVisible) {
      const image =
        this.state.source !== undefined ? (
          <Image
            style={[styles.image, this.props.imageStyle]}
            source={this.state.source}
            resizeMode={this.props.resizeMode}
          />
        ) : null;

      // RN-437: Opacity 0 prevents touch events on iOS.
      // Use the 'hidden' visibility instead.
      const opacity = this.state.opacity === 0 ? 1 : this.state.opacity;
      const visibility = this.state.opacity === 0 ? 'hidden' : 'visible';

      return (
        <Pressable
          style={[{opacity, visibility}, this.props.style]}
          disabled={this.state.disabled}
          onPress={() => {
            if (this.props.onPress) {
              this.props.onPress();
            }
          }}>
          {image}
        </Pressable>
      );
    } else {
      return null;
    }
  }
}

const styles = StyleSheet.create({
  image: {
    width: '100%',
    height: '100%',
  },
});

export default CLImage;
