import React, {Component} from 'react';
import {StyleSheet, View, Text, Pressable} from 'react-native';
import Colors from '../utils/Colors';

type OptionProps = {
  style?: any;
  title: string;
  labels: string[];
  value: number;
};

type OptionStates = {
  title: string;
  labels: string[];
  value: number;
};

class CLOption extends Component<OptionProps, OptionStates> {
  public constructor(props: OptionProps) {
    super(props);

    this.state = {
      title: props.title,
      labels: props.labels,
      value: props.value,
    };
  }

  render() {
    let labels = this.state.labels;
    let children = [];
    let borderRadius = 5;

    for (let i = 0; i < labels.length; i++) {
      children.push(
        <Pressable
          key={i}
          style={[
            styles.optionItem,
            {borderTopLeftRadius: i === 0 ? borderRadius : 0},
            {borderBottomLeftRadius: i === 0 ? borderRadius : 0},
            {borderTopRightRadius: i === labels.length - 1 ? borderRadius : 0},
            {
              borderBottomRightRadius:
                i === labels.length - 1 ? borderRadius : 0,
            },
            {borderRightWidth: i === labels.length - 1 ? 1 : 0},
            {
              backgroundColor:
                i === this.state.value ? Colors.theme3 : Colors.theme2,
            },
          ]}
          onPress={() => {
            this.setState({value: i});
          }}>
          <Text
            style={[
              styles.optionText,
              {color: i === this.state.value ? Colors.theme2 : Colors.theme3},
            ]}>
            {labels[i]}
          </Text>
        </Pressable>,
      );
    }

    return (
      <View style={[styles.optionContainer, this.props.style]}>
        <Text style={styles.title}> {this.state.title + ':'} </Text>
        {children}
      </View>
    );
  }
}

const styles = StyleSheet.create({
  title: {
    color: Colors.theme1,
    fontSize: 14,
    fontWeight: '600',
    marginRight: 10,
  },
  optionContainer: {
    alignSelf: 'baseline',
    flexDirection: 'row',
  },
  optionItem: {
    alignSelf: 'baseline',
    borderWidth: 1,
    borderColor: Colors.theme3,
    padding: 2,
  },
  optionText: {
    fontSize: 12,
  },
});

export default CLOption;
