import React, {Component} from 'react';
import {StyleSheet, Pressable, View} from 'react-native';
import Colors from '../utils/Colors';
import CLImage from './CLImage';

type Props = {
  isVisible?: boolean;
  style?: any;
  onPress?: () => void;
};

type States = {
  isVisible: boolean;
  isFocus: boolean;
};

class CLPipButton extends Component<Props, States> {
  public constructor(props: Props) {
    super(props);

    this.state = {
      isVisible: props.isVisible !== undefined ? props.isVisible : true,
      isFocus: false,
    };
  }

  render() {
    if (this.state.isVisible) {
      return (
        <Pressable
          style={this.props.style}
          onFocus={() => {
            this.setState({isFocus: true});
          }}
          onBlur={() => {
            this.setState({isFocus: false});
          }}
          onPress={() => {
            if (this.props.onPress) {
              this.props.onPress();
            }
          }}>
          <View style={this.state.isFocus ? styles.onFocus : styles.onBlur}>
            <CLImage
              style={styles.pip}
              imageStyle={styles.pipImage}
              disabled={true}
              source={require('../assets/images/picture_in_picture.png')}
            />
          </View>
        </Pressable>
      );
    } else {
      return null;
    }
  }
}

const styles = StyleSheet.create({
  pip: {
    width: '100%',
    height: '100%',
    position: 'absolute',
    justifyContent: 'center',
    alignItems: 'center',
  },
  pipImage: {
    width: '70%',
    height: '70%',
    tintColor: '#FFFFFF',
  },
  onFocus: {
    width: '100%',
    height: '100%',
    backgroundColor: Colors.buttonFocus,
  },
  onBlur: {
    width: '100%',
    height: '100%',
    backgroundColor: 'transparent',
  },
});

export default CLPipButton;
