import React, {Component} from 'react';
import {StyleSheet, Pressable, View} from 'react-native';
import Colors from '../utils/Colors';
import CLImage from './CLImage';

type Props = {
  isVisible?: boolean;
  style?: any;
  onPress?: () => void;
};

type States = {
  isVisible: boolean;
  isFocus: boolean;
};

class CLPlayButton extends Component<Props, States> {
  private isPlaying: boolean;
  private playImage: CLImage | null = null;
  private pauseImage: CLImage | null = null;

  public constructor(props: Props) {
    super(props);

    this.state = {
      isVisible: props.isVisible !== undefined ? props.isVisible : true,
      isFocus: false,
    };

    this.isPlaying = false;
  }

  render() {
    if (this.state.isVisible) {
      return (
        <Pressable
          style={this.props.style}
          onFocus={() => {
            this.setState({isFocus: true});
          }}
          onBlur={() => {
            this.setState({isFocus: false});
          }}
          onPress={() => {
            if (this.props.onPress) {
              this.props.onPress();
            }
          }}>
          <View style={this.state.isFocus ? styles.onFocus : styles.onBlur}>
            <CLImage
              ref={playImage => {
                this.playImage = playImage;
              }}
              style={styles.play}
              imageStyle={styles.playImage}
              isVisible={!this.isPlaying}
              disabled={true}
              source={require('../assets/images/play.png')}
            />
            <CLImage
              ref={pauseImage => {
                this.pauseImage = pauseImage;
              }}
              style={styles.pause}
              imageStyle={styles.pauseImage}
              isVisible={this.isPlaying}
              disabled={true}
              source={require('../assets/images/pause.png')}
            />
          </View>
        </Pressable>
      );
    } else {
      return null;
    }
  }

  public play() {
    this.isPlaying = true;
    this.refresh();
  }

  public pause() {
    this.isPlaying = false;
    this.refresh();
  }

  public toggle() {
    this.isPlaying = !this.isPlaying;
    this.refresh();
  }

  private refresh() {
    this.playImage?.setState({isVisible: !this.isPlaying});
    this.pauseImage?.setState({isVisible: this.isPlaying});
  }
}

const styles = StyleSheet.create({
  play: {
    width: '100%',
    height: '100%',
    position: 'absolute',
    justifyContent: 'center',
    alignItems: 'center',
  },
  pause: {
    width: '100%',
    height: '100%',
    position: 'absolute',
    justifyContent: 'center',
    alignItems: 'center',
  },
  playImage: {
    width: '80%',
    height: '80%',
    tintColor: '#FFFFFF',
  },
  pauseImage: {
    width: '70%',
    height: '70%',
    tintColor: '#FFFFFF',
  },
  onFocus: {
    width: '100%',
    height: '100%',
    backgroundColor: Colors.buttonFocus,
  },
  onBlur: {
    width: '100%',
    height: '100%',
    backgroundColor: 'transparent',
  },
});

export default CLPlayButton;
