import React, {Component} from 'react';
import {StyleSheet, View, LayoutChangeEvent} from 'react-native';

import {C} from '../../../src/index';
import Colors from '../utils/Colors';

type Props = {
  isVisible?: boolean;
  progress?: number;
  max?: number;
  style?: any;
};

type States = {
  isVisible: boolean;
};

class CLProgressbar extends Component<Props, States> {
  public x: number = C.UNSET;
  public y: number = C.UNSET;
  public width: number = C.UNSET;
  public height: number = C.UNSET;
  private progress: number;
  public max: number;
  private backgroundBar: Bar | null = null;
  private progressBar: Bar | null = null;

  public constructor(props: Props) {
    super(props);

    this.state = {
      isVisible: props.isVisible !== undefined ? props.isVisible : true,
    };

    this.progress = props.progress !== undefined ? props.progress : 0;
    this.max = props.max !== undefined ? props.max : 100;
  }

  render() {
    if (this.state.isVisible) {
      return (
        <View
          style={[styles.main, this.props.style]}
          onLayout={event => {
            this.onLayout(event);
          }}>
          <Bar
            ref={bar => {
              this.backgroundBar = bar;
            }}
            style={styles.backgroundBar}
            width={0}
          />
          <Bar
            ref={bar => {
              this.progressBar = bar;
            }}
            style={styles.progressBar}
            width={0}
          />
        </View>
      );
    } else {
      return null;
    }
  }

  private onLayout(event: LayoutChangeEvent) {
    let {x, y, width, height} = event.nativeEvent.layout;
    this.x = x;
    this.y = y;
    this.width = width;
    this.height = height;
    this.refresh();
  }

  public setProgress(progress: number) {
    this.progress = progress;
    this.refresh();
  }

  private refresh() {
    if (!this.state.isVisible || this.width === undefined) {
      return;
    }
    let progressWidth = (this.width * this.progress) / this.max;
    this.backgroundBar?.setState({width: this.width});
    this.progressBar?.setState({width: progressWidth});
  }
}

type BarProps = {
  isVisible?: boolean;
  width: number;
  style?: any;
};

type BarStates = {
  isVisible: boolean;
  width: number;
};

class Bar extends Component<BarProps, BarStates> {
  public constructor(props: BarProps) {
    super(props);

    this.state = {
      isVisible: props.isVisible !== undefined ? props.isVisible : true,
      width: props.width,
    };
  }

  render() {
    if (this.state.isVisible) {
      return (
        <View
          style={[this.props.style, styles.bar, {width: this.state.width}]}
        />
      );
    } else {
      return null;
    }
  }
}

const styles = StyleSheet.create({
  main: {
    justifyContent: 'center',
  },
  backgroundBar: {
    backgroundColor: '#00000033',
  },
  progressBar: {
    backgroundColor: Colors.theme1,
  },
  bar: {
    height: 4,
    position: 'absolute',
    borderRadius: 2,
  },
});

export default CLProgressbar;
