import React, {Component} from 'react';
import {
  StyleSheet,
  SectionList,
  TouchableOpacity,
  Text,
  View,
} from 'react-native';
import Colors from '../utils/Colors';

type Props = {
  isVisible?: boolean;
  data?: MenuItem[];
  style?: any;
  onPress: (item: Item) => void;
  onClose: () => void;
};

type States = {
  isVisible: boolean;
  data: MenuItem[];
};

export type Item = {
  index: number;
  title: string;
  selected: boolean;
  type: string;
};

export type MenuItem = {
  title: string;
  data: Item[];
};

class CLSelection extends Component<Props, States> {
  public constructor(props: Props) {
    super(props);

    this.state = {
      isVisible: props.isVisible !== undefined ? props.isVisible : true,
      data: props.data !== undefined ? props.data : [],
    };
  }

  render() {
    if (this.state.isVisible) {
      return (
        <View style={[styles.main, this.props.style]}>
          <View style={styles.closeWrapper}>
            <TouchableOpacity
              style={styles.closeButton}
              onPress={() => {
                this.props.onClose();
              }}>
              <Text style={styles.closeText}>Close</Text>
            </TouchableOpacity>
          </View>
          <SectionList
            sections={this.state.data}
            keyExtractor={(item: Item, index: number) => item.title + index}
            renderItem={({item}) => (
              <TouchableOpacity
                onPress={() => {
                  this.props.onPress(item);
                }}>
                <Text
                  style={item.selected ? styles.selectedText : styles.itemText}>
                  {item.title}
                </Text>
              </TouchableOpacity>
            )}
            renderSectionHeader={({section: {title}}) => (
              <Text style={styles.headerText}>{title}</Text>
            )}
          />
        </View>
      );
    } else {
      return null;
    }
  }
}

const styles = StyleSheet.create({
  main: {
    backgroundColor: '#FFFFFF',
    borderRadius: 10,
    top: 60,
    bottom: 100,
    left: 20,
    right: 20,
    padding: 20,
  },
  itemText: {
    fontSize: 14,
    color: '#777777',
    marginLeft: 20,
    marginTop: 8,
  },
  selectedText: {
    fontSize: 14,
    color: '#FFFFFF',
    marginLeft: 15,
    marginRight: 15,
    marginTop: 8,
    backgroundColor: Colors.theme1,
    borderRadius: 5,
    paddingLeft: 5,
    paddingTop: 2,
    paddingBottom: 2,
  },
  headerText: {
    fontSize: 16,
    color: '#333333',
    marginTop: 8,
  },
  closeWrapper: {
    height: 20,
  },
  closeButton: {
    position: 'absolute',
    right: 20,
  },
  closeText: {
    fontSize: 14,
    color: '#FF0000',
  },
});

export default CLSelection;
