import React, {Component} from 'react';
import {Text, StyleSheet} from 'react-native';

type Props = {
  isVisible?: boolean;
  position?: number;
  duration?: number;
  style?: any;
};

type States = {
  isVisible: boolean;
  isLive: boolean;
  position: number;
  duration: number;
};

class CLTime extends Component<Props, States> {
  public constructor(props: Props) {
    super(props);

    this.state = {
      isLive: false,
      isVisible: props.isVisible !== undefined ? props.isVisible : true,
      position: props.position !== undefined ? props.position : 0,
      duration: props.duration !== undefined ? props.duration : 0,
    };
  }

  render() {
    if (this.state.isVisible) {
      if (this.state.isLive) {
        return <Text style={[styles.text, this.props.style]}>{'Live'}</Text>;
      } else {
        return (
          <Text style={[styles.text, this.props.style]}>
            {this.getFinalText()}
          </Text>
        );
      }
    } else {
      return null;
    }
  }

  public setPosition(position: number) {
    this.setState({position: position});
  }

  public setDuration(duration: number) {
    this.setState({duration: duration});
  }

  private getFinalText(): string {
    let position = this.format(this.state.position);
    let duration = this.format(this.state.duration);
    return position + ' / ' + duration;
  }

  private format(position: number): string {
    position = Math.floor(position);

    let hours = Math.floor(position / 3600);
    let minutes = Math.floor((position - hours * 3600) / 60);
    let seconds = position - hours * 3600 - minutes * 60;

    let strH = hours.toString().padStart(2, '0');
    let strM = minutes.toString().padStart(2, '0');
    let strS = seconds.toString().padStart(2, '0');

    return strH + ':' + strM + ':' + strS;
  }
}

const styles = StyleSheet.create({
  text: {
    fontSize: 16,
    color: '#FFFFFF',
  },
});

export default CLTime;
