import React, {useCallback} from 'react';
import {StyleSheet, Text, TouchableOpacity, View} from 'react-native';
import GoogleCast, {useMediaStatus} from 'react-native-google-cast';
import Colors from '../utils/Colors';
import MediaPlayerState from 'react-native-google-cast/src/types/MediaPlayerState';

function CastMiniController() {
  const onPress = useCallback(() => {
    GoogleCast.showExpandedControls();
  }, []);

  const mediaStatus = useMediaStatus();
  if (!mediaStatus || mediaStatus.playerState === MediaPlayerState.IDLE) {
    return null;
  }

  const mediaTitle = mediaStatus.mediaInfo?.metadata?.title ?? 'Unknown';

  return (
    <TouchableOpacity style={styles.container} onPress={onPress}>
      <View>
        <Text style={[styles.label, styles.info]}>Casting</Text>
        <Text style={styles.label}>{mediaTitle}</Text>
      </View>
    </TouchableOpacity>
  );
}

const styles = StyleSheet.create({
  container: {
    flexDirection: 'column',
    justifyContent: 'center',
    alignItems: 'flex-start',
    width: '100%',
    backgroundColor: Colors.theme6,
    padding: 10,
    borderTopWidth: 1,
    borderTopColor: Colors.theme3,
  },
  label: {
    padding: 5,
    color: Colors.theme1,
  },
  info: {
    color: Colors.theme3,
    fontSize: 12,
  },
});

export default CastMiniController;
