import {StyleSheet, Text, TouchableOpacity, View} from 'react-native';
import React, {useCallback} from 'react';
import Demo from '../models/Demo';
import Colors from '../utils/Colors';
import MsgBundle from '../utils/MsgBundle';
import ScreenTags from '../screens/ScreenTags';
import {useRemoteMediaClient} from 'react-native-google-cast';
import CastService from '../services/CastService';
import NavigationService from '../services/NavigationService';

type Props = {
  demo: Demo;
};

function DemoCard(props: Props) {
  const castRemoteMediaClient = useRemoteMediaClient();

  const onPress = useCallback(() => {
    if (castRemoteMediaClient) {
      CastService.instance?.castFromDemo(props.demo);
    } else {
      MsgBundle.set('title', props.demo.title);
      MsgBundle.set('media', props.demo.media);
      MsgBundle.set('canCast', props.demo.canCast);
      NavigationService.navigate(ScreenTags.Player);
    }
  }, [castRemoteMediaClient, props.demo]);

  return (
    <TouchableOpacity style={[styles.card]} onPress={onPress}>
      <View>
        <Text style={styles.cardTitle}>{props.demo.title} </Text>
        <Text style={styles.cardDescription}>{props.demo.description} </Text>
      </View>
    </TouchableOpacity>
  );
}

const styles = StyleSheet.create({
  card: {
    flex: 1,
    padding: 10,
    width: '80%',
    backgroundColor: Colors.theme2,
    borderRadius: 10,
    borderWidth: 1,
    borderColor: Colors.theme1,
    justifyContent: 'flex-start',
    alignSelf: 'center',
    marginBottom: 20,
  },
  cardTitle: {
    color: Colors.theme1,
    fontSize: 14,
    fontWeight: '600',
  },
  cardDescription: {
    color: Colors.theme3,
    fontSize: 12,
    marginTop: 5,
  },
});

export default DemoCard;
