import {Component} from 'react';
import {BackHandler} from 'react-native';

export type ScreenProps = {
  navigation?: any;
};

abstract class Screen<T> extends Component<ScreenProps, T> {
  private backHandler: any;

  protected constructor(props: ScreenProps) {
    super(props);
    props.navigation.addListener('focus', () => {
      this.onFocus();
    });
    props.navigation.addListener('blur', () => {
      this.onBlur();
    });
    props.navigation.addListener('beforeRemove', (e: any) => {
      this.onBeforeRemove(e);
    });
  }

  public onFocus() {
    this.backHandler = BackHandler.addEventListener('hardwareBackPress', () => {
      this.onBack();
      return true;
    });
  }

  public onBlur() {
    this.backHandler.remove();
  }

  public onBack() {
    this.props.navigation.pop();
  }

  // eslint-disable-next-line @typescript-eslint/no-unused-vars
  public onBeforeRemove(e: any) {}
}

export default Screen;
