import React from 'react';
import {FlatList, Platform, StyleSheet, View} from 'react-native';
import AppBar from '../components/AppBar';
import CastMiniController from '../components/CastMiniController';
import DemoCard from '../components/DemoCard';
import demoList from '../assets/demoList';
import {useRemoteMediaClient} from 'react-native-google-cast';

export default function DemosScreen() {
  const client = useRemoteMediaClient();

  const iOS = Platform.OS === 'ios';

  const demos = demoList
    .filter(demo => (iOS ? demo.showOnApple : demo.showOnAndroid))
    .filter(demo => (client ? demo.canCast : true));

  return (
    <View style={styles.main}>
      <AppBar />
      <FlatList
        style={styles.demoList}
        contentContainerStyle={styles.demoListBody}
        data={demos}
        renderItem={({item}) => <DemoCard demo={item} />}
        numColumns={1}
        keyExtractor={item => item.id}
      />
      <CastMiniController />
    </View>
  );
}

const styles = StyleSheet.create({
  main: {
    flex: 1,
  },
  demoList: {
    width: '100%',
    height: '100%',
  },
  demoListBody: {
    paddingTop: 30,
    paddingBottom: 10,
  },
});
