import React from 'react';
import {
  Platform,
  StyleSheet,
  View,
  Text,
  TouchableOpacity,
  Image,
  FlatList,
} from 'react-native';
import Colors from '../utils/Colors';
import ScreenTags from './ScreenTags';
import Screen, {ScreenProps} from '../components/Screen';

export type MenuItem = {
  id: string;
  title: string;
  screenTag: string;
};

class MainScreen extends Screen<{}> {
  private MenuItems: MenuItem[] = this.getMenuItems();

  public constructor(props: ScreenProps) {
    super(props);
  }

  render() {
    return (
      <View style={styles.main}>
        <Text style={styles.title}> PRESTOplay React Demos </Text>
        <View style={styles.listContainer}>
          <FlatList
            style={styles.flatList}
            data={this.MenuItems}
            numColumns={1}
            renderItem={({item}) => (
              <TouchableOpacity
                style={styles.itemContainer}
                onPress={() => {
                  this.props.navigation.navigate(item.screenTag);
                }}>
                <Text style={styles.itemText}> {item.title} </Text>
                <Image
                  style={styles.itemImage}
                  source={require('../assets/images/play.png')}
                />
              </TouchableOpacity>
            )}
            keyExtractor={item => item.id}
          />
        </View>
      </View>
    );
  }

  private getMenuItems(): MenuItem[] {
    let items: MenuItem[] = [];

    if (!Platform.isTV) {
      let item1: MenuItem = {
        id: '1',
        title: 'Player',
        screenTag: ScreenTags.Demos,
      };
      items.push(item1);
    }

    if (!Platform.isTV) {
      let item2: MenuItem = {
        id: '2',
        title: 'Downloader',
        screenTag: ScreenTags.Download,
      };
      items.push(item2);
    }

    if (Platform.isTV) {
      if (Platform.OS === 'ios') {
        let item3: MenuItem = {
          id: '3',
          title: 'Apple TV Player',
          screenTag: ScreenTags.AppleTVDemos,
        };
        items.push(item3);
      }
    }

    return items;
  }
}

const styles = StyleSheet.create({
  main: {
    flex: 1,
    flexDirection: 'column',
    justifyContent: 'center',
    alignItems: 'center',
  },
  title: {
    fontSize: 18,
    fontWeight: '600',
    marginBottom: 30,
    color: Colors.theme3,
  },
  itemContainer: {
    width: 220,
    height: 60,
    marginTop: 20,
    backgroundColor: Colors.theme1,
    borderRadius: 10,
    justifyContent: 'center',
  },
  itemText: {
    color: Colors.theme2,
    fontSize: 16,
    fontWeight: '600',
    position: 'absolute',
    left: 10,
  },
  itemImage: {
    width: 30,
    height: 30,
    tintColor: Colors.theme2,
    position: 'absolute',
    right: 10,
  },
  listContainer: {
    height: '60%',
  },
  flatList: {
    width: '100%',
    height: '100%',
  },
});

export default MainScreen;
