//
//  PictureInPictureEventModule.m
//  Pods
//
//  Created by Taewoo Kim on 14/11/22.
//

#import <Foundation/Foundation.h>
#import "PictureInPictureEventModule.h"
#import <PRESTOplay/PRESTOplay-Swift.h>
#import <AVKit/AVKit.h>
#import <React/RCTLog.h>
#import "react_native_prestoplay-Swift.h"

// NOTE: Unlike other events, when returning from PiP mode, events cannot be forwarded to the RN side with RCT_EXPORT_VIEW_PROPERTY method.
//       So we pass the PiP events through this module.

NSNotificationName const PICTURE_IN_PICTURE_WILL_START = @"picture-in-picture-will-start";
NSNotificationName const RESTORE_USER_INTERFACE_FOR_PICTURE_IN_PICTURE_STOP = @"restore-user-interface-for-picture-in-picture-stop";
NSNotificationName const PICTURE_IN_PICTURE_DID_STOP = @"picture-in-picture-did-stop";

#define ON_PIP_EVENT @"onPictureInPictureEvent"

API_AVAILABLE(tvos(15.0))
@interface PictureInPictureEventModule()
@property (nonatomic, assign) BOOL hasListeners;
@end

API_AVAILABLE(tvos(15.0))
@implementation PictureInPictureEventModule

RCT_EXPORT_MODULE();

- (NSArray<NSString *> *)supportedEvents {
    return @[ON_PIP_EVENT];
}

- (void)startObserving {
    self.hasListeners = YES;
    [[NSNotificationCenter defaultCenter] addObserver:self
                                             selector:@selector(pictureInPictureWillStart)
                                                 name:PICTURE_IN_PICTURE_WILL_START
                                               object:nil];

    [[NSNotificationCenter defaultCenter] addObserver:self
                                             selector:@selector(restoreUserInterfaceForPictureInPictureStop)
                                                 name:RESTORE_USER_INTERFACE_FOR_PICTURE_IN_PICTURE_STOP
                                               object:nil];

    [[NSNotificationCenter defaultCenter] addObserver:self
                                             selector:@selector(pictureInPictureDidStop)
                                                 name:PICTURE_IN_PICTURE_DID_STOP
                                               object:nil];
}

- (void)stopObserving {
    self.hasListeners = NO;
    [[NSNotificationCenter defaultCenter] removeObserver:self];
}

- (void)pictureInPictureWillStart {
    if (self.hasListeners) {
        [self sendEventWithName:ON_PIP_EVENT body:@{@"id": PICTURE_IN_PICTURE_WILL_START}];
    }
}

- (void)restoreUserInterfaceForPictureInPictureStop {
    if (self.hasListeners) {
        [self sendEventWithName:ON_PIP_EVENT body:@{@"id": RESTORE_USER_INTERFACE_FOR_PICTURE_IN_PICTURE_STOP}];
    }
}

- (void)pictureInPictureDidStop {
    if (self.hasListeners) {
        [self sendEventWithName:ON_PIP_EVENT body:@{@"id": PICTURE_IN_PICTURE_DID_STOP}];
    }
}

@end

