//
//  TVPlayerModuleUtils.swift
//  react-native-prestoplay-module
//
//  Created by Mackode - Taewoo Kim on 19/06/2023.
//

import CoreMedia
import Foundation
import PRESTOplay

extension ActionPopupMenuInfo {
    public convenience init?(from dic: NSDictionary) {
        guard let title = dic["title"] as? String else { return nil }
        guard let imageName = dic["imageName"] as? String else { return nil }
        guard let actions = dic["actions"] as? NSArray else { return nil }

        let actionInfos: [ActionButtonInfo] = actions.compactMap {
            guard let actionDic = $0 as? NSDictionary else { return nil }
            return ActionButtonInfo(from: actionDic)
        }

        self.init(title: title, imageName: imageName, actionInfos: actionInfos)
    }
}

extension ActionButtonInfo {
    public convenience init?(from dic: NSDictionary) {
        guard let id = dic["id"] as? String else { return nil }
        guard let title = dic["title"] as? String else { return nil }

        var subMenuInfo: ActionSubMenuInfo?
        if let subMenu = dic["subMenu"] as? NSDictionary {
            subMenuInfo = ActionSubMenuInfo(from: subMenu)
        }

        self.init(
            id: id,
            title: title,
            imageName: dic["imageName"] as? String,
            subMenu: subMenuInfo
        )
    }
}

extension ActionSubMenuInfo {
    public convenience init?(from dic: NSDictionary) {
        guard let menuItems = dic["menuItems"] as? NSArray else { return nil }

        let defaultValue = dic["defaultValue"] as? String
        let subMenuItemInfos: [ActionSubMenuItemInfo] = menuItems.compactMap {
            guard let menuItemDic = $0 as? NSDictionary else { return nil }
            return ActionSubMenuItemInfo(from: menuItemDic)
        }

        self.init(defaultValue: defaultValue, menuItems: subMenuItemInfos)
    }
}

extension ActionSubMenuItemInfo {
    public convenience init?(from dic: NSDictionary) {
        guard let title = dic["title"] as? String else { return nil }
        guard let value = dic["value"] as? String else { return nil }

        self.init(title: title, value: value)
    }
}

extension ContextualActionButtonInfo {
    public convenience init?(from dic: NSDictionary) {
        guard let id = dic["id"] as? String else { return nil }
        guard let title = dic["title"] as? String else { return nil }
        guard let startSecond = dic["startSecond"] as? CMTimeValue else { return nil }
        guard let endSecond = dic["endSecond"] as? CMTimeValue else { return nil }

        self.init(
            id: id,
            title: title,
            imageName: dic["imageName"] as? String,
            startSecond: startSecond,
            endSecond: endSecond
        )
    }
}
