import GenericCallback from './GenericCallback';
import NewInstanceCallback from './NewInstanceCallback';
import StateChangedCallback from './StateChangedCallback';
import SeekToCallback from './SeekToCallback';
import ThumbnailLoadedCallback from './ThumbnailLoadedCallback';
import ErrorCallback from './ErrorCallback';
import PlayerConfiguration from './PlayerConfiguration';
import Playlist from '../utils/Playlist';
export default interface CLVideoProps {
    style?: any;
    /**
     *  Media to be played. It can be a single player configuration or a playlist.
     *
     *  Downloaded media doesn't work with playlists on Apple devices.
     *  We recommend using the single player configuration for downloaded media.
     *
     *  @exmaple
     *  ```jsx
     *  media={{
     *    source: 'https://demo.cf.castlabs.com/media/prestohls/master.m3u8',
     *  }}
     *  ```
     */
    media: PlayerConfiguration | Playlist;
    /** Function to be triggered on view created. */
    onViewCreated?: NewInstanceCallback;
    /** Function to be triggered on state changed. */
    onStateChanged?: StateChangedCallback;
    /** Function to be triggered on error. */
    onError?: ErrorCallback;
    /** Function to be triggered on seeking to another position. */
    onSeekTo?: SeekToCallback;
    /** Function to be triggered on seeking completed. */
    onSeekCompleted?: GenericCallback;
    /** Function to be triggered on fully buffered. */
    onFullyBuffered?: GenericCallback;
    /** Function to be triggered on thumbnail loaded. */
    onThumbnailLoaded?: ThumbnailLoadedCallback;
    /** Function to be triggered on metadata changed. */
    onPlayerModelChanged?: GenericCallback;
}
