import Playlist from '../utils/Playlist';
import { Platform } from 'react-native';
import DrmSystem from './DrmSystem';
import SourceUtils from '../utils/SourceUtils';
/**
 * @ignore
 */
export default class MediaLoadRequest {
    usePlaylist;
    startAt;
    items;
    constructor(usePlaylist, startAt, items) {
        this.usePlaylist = usePlaylist;
        this.startAt = startAt;
        this.items = items.map(item => this.filterUnsupportedSources(item));
    }
    filterUnsupportedSources(playerConfiguration) {
        playerConfiguration = { ...playerConfiguration };
        if (Platform.OS === 'android') {
            playerConfiguration.drmSystem = DrmSystem.AUTO;
            playerConfiguration.source = SourceUtils.findMatchedSource(SourceUtils.getSources(playerConfiguration), SourceUtils.ANDROID_FILTERS);
        }
        if (Platform.OS === 'ios') {
            playerConfiguration.drmSystem = DrmSystem.FAIRPLAY;
            playerConfiguration.source = SourceUtils.findMatchedSource(SourceUtils.getSources(playerConfiguration), SourceUtils.IOS_FILTERS);
        }
        return playerConfiguration;
    }
    toJSON() {
        return JSON.stringify({
            usePlaylist: this.usePlaylist,
            startAt: this.startAt,
            items: this.items,
        });
    }
    static fromMedia(media) {
        return media instanceof Playlist
            ? new MediaLoadRequest(true, media.currentIndex, media.items)
            : new MediaLoadRequest(false, 0, [media]);
    }
}
