/**
 * Contains statistics and information about the current state of the player.
 * This is for applications that want to log quality of experience (QoE) or other statistics.
 * These values are reset each time a new stream is loaded.
 */
export default interface Stats {
    /**
     * The total number of frames dropped by the Player.
     */
    droppedFrames: number;
    /**
     * The total bandwidth required for the current streams, in bits per second.
     */
    streamBandwidth?: number;
    /**
     * The current estimated network bandwidth, in bits per second.
     */
    estimatedBandwidth?: number;
    /**
     * The accumulated duration, in seconds, of active network transfer of bytes.
     * @remarks Not supported on Android.
     */
    transferDurationSec?: number;
    /**
     * The accumulated number of bytes transferred over the network.
     * @remarks Not supported on Android.
     */
    numberOfBytesTransferred?: number;
    /**
     * The number of media read requests from the server to this client.
     * @remarks Not supported on Android.
     */
    numberOfMediaRequests?: number;
    /**
     * The Unix Epoch time, in milliseconds, at which playback began.
     * @remarks Not supported on Android.
     */
    playbackStartTimestamp?: number;
    /**
     * The accumulated duration, in seconds, until the player item is ready to play.
     * @remarks Not supported on Android.
     */
    startupTimeSec?: number;
    /**
     * The accumulated duration, in seconds, of the media played.
     * @remarks Not supported on Android.
     */
    durationWatchedSec?: number;
    /**
     * The total number of playback stalls encountered.
     * @remarks Not supported on Android.
     */
    numberOfStalls?: number;
    /**
     * The accumulated duration, in seconds, of the media segments downloaded.
     * @remarks Not supported on Android.
     */
    segmentsDownloadedDurationSec?: number;
    /**
     * The standard deviation of the observed segment download bit rates.
     * @remarks Not supported on Android.
     */
    observedBitrateStandardDeviation?: number;
    /**
     * The empirical throughput, in bits per second, across all media downloaded.
     * @remarks Not supported on Android.
     */
    observedBitrate?: number;
    /**
     * The audio track’s average bit rate, in bits per second.
     * @remarks Not supported on Android.
     */
    averageAudioBitrate?: number;
    /**
     * The video track’s average bit rate, in bits per second.
     * @remarks Not supported on Android.
     */
    averageVideoBitrate?: number;
    /**
     * The average throughput, in bits per second, required to play the stream, as advertised by the server.
     * @remarks Not supported on Android.
     */
    indicatedAverageBitrate?: number;
    /**
     * The throughput, in bits per second, required to play the stream, as advertised by the server.
     * @remarks Not supported on Android.
     */
    indicatedBitrate?: number;
}
