import PlayerConfiguration from '../types/PlayerConfiguration';
import { MediaStatus } from 'react-native-google-cast';
import CustomDrmConfiguration from '../types/CustomDrmConfiguration';
import DrmTodayConfiguration from '../types/DrmTodayConfiguration';
import DrmTodayOnboardConfiguration from '../types/DrmTodayOnboardConfiguration';
/**
 * Converts a MediaStatus object to a {@link PlayerConfiguration} object.
 * The MediaStatus is part of the
 * {@link https://github.com/react-native-google-cast/react-native-google-cast react-native-google-cast} library.
 */
export default class MediaStatusUtils {
    /**
     * Converts a MediaStatus object to a {@link PlayerConfiguration} object.
     *
     * The player configuration contains the current player state, position, audio track and text track.
  
     * An optional DRM configuration can be provided to override the one in the player configuration.
     * This is particularly useful if the DRM configuration contains authentication tokens that may be already expired.
     *
     * @example
     * ```jsx
     * const playerConfiguration = MediaStatusUtils.toPlayerConfiguration(
     *    this.mediaStatus,
     * );
     * // ...
     * <CLVideo media={playerConfiguration} />
     * ```
     * @param mediaStatus The media status
     * @param drmConfiguration The optional DRM configuration
     * @returns The player configuration
     */
    static toPlayerConfiguration(mediaStatus: MediaStatus, drmConfiguration?: DrmTodayConfiguration | DrmTodayOnboardConfiguration | CustomDrmConfiguration): PlayerConfiguration | null;
    private static toPreferredAudioLanguage;
    private static toPreferredTextLanguage;
    private static toStartTime;
}
