import ContentType from '../types/ContentType';
class SourceUtils {
    static CHROMECAST_FILTERS = [
        { type: ContentType.DASH, canPlayProtected: true, canPlayClear: true },
        { type: ContentType.SMOOTH, canPlayProtected: true, canPlayClear: true },
        { type: ContentType.HLS, canPlayProtected: false, canPlayClear: true },
        { type: ContentType.MP4, canPlayProtected: false, canPlayClear: true },
    ];
    static ANDROID_FILTERS = [
        { type: ContentType.DASH, canPlayProtected: true, canPlayClear: true },
        { type: ContentType.SMOOTH, canPlayProtected: true, canPlayClear: true },
        { type: ContentType.HLS, canPlayProtected: false, canPlayClear: true },
        { type: ContentType.MP4, canPlayProtected: false, canPlayClear: true },
    ];
    static IOS_FILTERS = [
        { type: ContentType.HLS, canPlayProtected: true, canPlayClear: true },
        { type: ContentType.MP4, canPlayProtected: false, canPlayClear: true },
    ];
    static normalizeSource(source) {
        source = { ...source }; // shallow copy
        source.drmProtected = source.drmProtected ?? false;
        if (!source.type) {
            const urlNoParams = source.url.split('?')[0].toLowerCase();
            if (urlNoParams.endsWith('.mpd')) {
                source.type = ContentType.DASH;
            }
            else if (urlNoParams.endsWith('.manifest') ||
                urlNoParams.endsWith('.ism')) {
                source.type = ContentType.SMOOTH;
            }
            else if (urlNoParams.endsWith('.m3u8') ||
                urlNoParams.endsWith('.movpkg') ||
                urlNoParams.endsWith('.movpkg/')) {
                source.type = ContentType.HLS;
            }
            else if (urlNoParams.endsWith('.mp4')) {
                source.type = ContentType.MP4;
            }
            else {
                throw new Error('Could not determine content type');
            }
        }
        return source;
    }
    static getSources(playerConfiguration) {
        const sources = [];
        if (Array.isArray(playerConfiguration.source)) {
            sources.push(...playerConfiguration.source);
        }
        else if (typeof playerConfiguration.source === 'object') {
            sources.push(playerConfiguration.source);
        }
        else {
            sources.push({ url: playerConfiguration.source });
        }
        return sources.map(s => SourceUtils.normalizeSource(s));
    }
    static findMatchedSource(sources, filters) {
        for (const filter of filters) {
            const source = sources.find(s => {
                // prettier-ignore
                return (s.type === filter.type && ((s.drmProtected === true && filter.canPlayProtected) ||
                    (s.drmProtected === false && filter.canPlayClear)));
            });
            if (source !== undefined) {
                return source;
            }
        }
        throw new Error('No source found');
    }
}
export default SourceUtils;
