import React, {Component} from 'react';
import {
  View,
  StyleSheet,
  requireNativeComponent,
  LayoutChangeEvent,
  NativeSyntheticEvent,
} from 'react-native';
import C from '../utils/Constants';
import CLThumbnailProps from '../types/CLThumbnailProps';

const ThumbnailView = requireNativeComponent('ThumbnailView');

type States = {
  isVisible: boolean;
  left: number;
};

type ViewCreatedData = {
  instanceId: number;
};

/**
 * @example
 * ```typescript
 * import {CLThumbnail} from '@castlabs/react-native-prestoplay';
 * ```
 * @noInheritDoc
 */
class CLThumbnail extends Component<CLThumbnailProps, States> {
  public instanceId: number = C.UNSET;
  public x: number = C.UNSET;
  public y: number = C.UNSET;
  public width: number = C.UNSET;
  public height: number = C.UNSET;

  public constructor(props: CLThumbnailProps) {
    super(props);

    this.state = {
      isVisible: props.isVisible !== undefined ? props.isVisible : false,
      left: props.style.left,
    };
  }

  render() {
    return (
      <View
        style={[
          this.props.style,
          {
            left: this.state.left,
            opacity: this.state.isVisible ? 1 : 0,
          },
        ]}>
        <ThumbnailView
          // @ts-ignore (style property)
          style={styles.thumbnail}
          onLayout={(event: LayoutChangeEvent) => {
            this.onLayout(event);
          }}
          onViewCreated={(event: NativeSyntheticEvent<ViewCreatedData>) => {
            this.onViewCreated(event);
          }}
        />
      </View>
    );
  }

  //=================================
  //============  Events  ===========
  //=================================

  onLayout(event: LayoutChangeEvent) {
    let {x, y, width, height} = event.nativeEvent.layout;
    this.x = x;
    this.y = y;
    this.width = width;
    this.height = height;
  }

  onViewCreated(event: NativeSyntheticEvent<ViewCreatedData>) {
    this.instanceId = event.nativeEvent.instanceId;
    if (this.props.onViewCreated) {
      this.props.onViewCreated(this.instanceId);
    }
  }
}

const styles = StyleSheet.create({
  thumbnail: {
    width: '100%',
    height: '100%',
  },
});

export default CLThumbnail;
