import AndroidCatchupConfigurationTimeReference from './AndroidCatchupConfigurationTimeReference';
import AndroidCatchupConfigurationType from './AndroidCatchupConfigurationType';

export default interface AndroidCatchupConfigurationSpeed {
  /**
   * The time reference to which the thresholds will be relative to.
   */
  timeReference: AndroidCatchupConfigurationTimeReference;

  /**
   * The strategy of the catchup behaviour.
   * @see {@link AndroidCatchupConfigurationType}
   */
  type: AndroidCatchupConfigurationType.Speed;

  /**
   * Threshold relative to the {@link AndroidCatchupConfiguration.timeReference} which indicates the start trigger of the Catchup.
   */
  upperTimeThresholdMs: number;

  /**
   * Threshold relative to the {@link AndroidCatchupConfiguration.timeReference} which indicates the end or destination of the Catchup.
   */
  lowerTimeThresholdMs: number;

  /**
   * Threshold relative to the {@link AndroidCatchupConfiguration.timeReference} which indicates a fallback safeguard for the speed mode.
   */
  fallbackTimeThresholdMs?: number;

  /**
   * Player speed at which to perform Catchup when {@link AndroidCatchupConfiguration.upperTimeThresholdMs} is reached.
   */
  speedCoefficient: number;

  /**
   * Directs the player seek to Catchup Upper Time Threshold on Video Segment Download Timeout Errors.
   */
  seekOnDownloadError?: boolean;
}
