/**
 * The behaviour of the player when a secondary display is connected.
 */
enum AndroidSecondaryDisplayBehaviour {
  /**
   * Never allow display on a secondary (i.e. mirrored or HDMI) display.
   */
  Never = 'never',

  /**
   * Allow display on a secondary (i.e. mirrored or HDMI)
   * display of unprotected content.
   */
  AllowUnprotectedContent = 'allowUnprotectedContent',

  /**
   * Allow display on a secondary (i.e. mirrored or HDMI)
   * display of protected content if the display reports
   * that its secure and supports protected buffers.
   * Please keep in mind, a DRM license can prevent playback on secondary,
   * insecure, or remote screens.
   */
  AllowSecureDisplay = 'allowSecureDisplay',

  /**
   * Always allow display on a secondary (i.e. mirrored or HDMI)
   * Please keep in mind, a DRM license can prevent playback on secondary,
   * insecure, or remote screens.
   */
  AllowAlways = 'allowAlways',
}

export default AndroidSecondaryDisplayBehaviour;
