export default interface ChannelInterstitialView {
  /**
   * The XIB file name for the view in the Xcode application project.
   * The file is searched first in the bundle's language-specific project directories, then in the Resources directory.
   * See the [Apple document](https://developer.apple.com/documentation/uikit/uinib/1614138-init).
   */
  xibName: string;
  /**
   * Array of text components in the view.
   * The texts are displayed by [UILabel](https://developer.apple.com/documentation/uikit/uilabel).
   * The key is the UILabel tag number.
   * You can set the tag number in the Xcode Interface Builder.
   */
  labels: {[key: number]: string}[];

  /**
   * Array of image components in the view.
   * The images are displayed by [UIImageView](https://developer.apple.com/documentation/uikit/uiimageview).
   * The key is the UILabel tag number.
   * The image component is the name of the image resource in the Xcode app project
   * or the URL of a local or remote image file.
   */
  images: {[key: number]: string}[];
}
