import PlayerConfiguration from './PlayerConfiguration';
import Media from './Media';
import Playlist from '../utils/Playlist';
import {Platform} from 'react-native';
import DrmSystem from './DrmSystem';
import SourceUtils from '../utils/SourceUtils';

/**
 * @ignore
 */
export default class MediaLoadRequest {
  readonly usePlaylist: boolean;
  readonly startAt: number;
  readonly items: PlayerConfiguration[];

  private constructor(
    usePlaylist: boolean,
    startAt: number,
    items: ReadonlyArray<PlayerConfiguration>,
  ) {
    this.usePlaylist = usePlaylist;
    this.startAt = startAt;
    this.items = items.map(item => this.filterUnsupportedSources(item));
  }

  private filterUnsupportedSources(
    playerConfiguration: PlayerConfiguration,
  ): PlayerConfiguration {
    playerConfiguration = {...playerConfiguration};

    if (Platform.OS === 'android') {
      playerConfiguration.drmSystem = DrmSystem.AUTO;
      playerConfiguration.source = SourceUtils.findMatchedSource(
        SourceUtils.getSources(playerConfiguration),
        SourceUtils.ANDROID_FILTERS,
      );
    }

    if (Platform.OS === 'ios') {
      playerConfiguration.drmSystem = DrmSystem.FAIRPLAY;
      playerConfiguration.source = SourceUtils.findMatchedSource(
        SourceUtils.getSources(playerConfiguration),
        SourceUtils.IOS_FILTERS,
      );
    }

    return playerConfiguration;
  }

  public toJSON(): string {
    return JSON.stringify({
      usePlaylist: this.usePlaylist,
      startAt: this.startAt,
      items: this.items,
    });
  }

  public static fromMedia(media: Media): MediaLoadRequest {
    return media instanceof Playlist
      ? new MediaLoadRequest(true, media.currentIndex, media.items)
      : new MediaLoadRequest(false, 0, [media]);
  }
}
